# PyStratum-Middle

The glue between a PyStratum middle and your application.

<table>
<thead>
<tr>
<th>Social</th>
<th>Release</th>
<th>Code</th>
</tr>
</thead>
<tbody>
<tr>
<td>
<a href="https://gitter.im/SetBased/py-stratum?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge"><img src="https://badges.gitter.im/SetBased/py-stratum.svg" alt="Gitter"/></a>
</td>
<td>
<a href="https://badge.fury.io/py/PyStratum-Middle"><img src="https://badge.fury.io/py/PyStratum-Middle.svg" alt="Latest Stable Version"/></a><br/>
</td>
<td>
<a href="https://scrutinizer-ci.com/g/DatabaseStratum/py-stratum-middle/?branch=master"><img src="https://scrutinizer-ci.com/g/DatabaseStratum/py-stratum-middle/badges/quality-score.png?b=master" alt="Scrutinizer Code Quality"/></a>
</td>
</tr>
</tbody>
</table>

## Overview

PyStratum is a tool and library for loading and invoking stored procedures from Python code.

The documentation of PyStratum is available at https://stratum.readthedocs.io/.

## License

This project is licensed under the terms of the MIT license.
